@@ -33,7 +33,6 @@ class KCheckableProxyModel;
 class QAbstractProxyModel;
 class QAbstractItemModel;
 class ColorProxyModel;
-class CalendarCategoriesModel;
 
 class CalendarManager : public QObject
 {
@@ -76,8 +75,14 @@ public:
     Q_INVOKABLE int getCalendarSelectableIndex(IncidenceWrapper *incidenceWrapper);
     QVariantMap undoRedoData();
 
+    Q_INVOKABLE Akonadi::Item incidenceItem(KCalendarCore::Incidence::Ptr incidence);
     Q_INVOKABLE void addIncidence(IncidenceWrapper *incidenceWrapper);
     Q_INVOKABLE void editIncidence(IncidenceWrapper *incidenceWrapper);
+    Q_INVOKABLE void updateIncidenceDates(IncidenceWrapper *incidenceWrapper,
+                                          int startOffset,
+                                          int endOffset,
+                                          int occurrences = -1,
+                                          const QDateTime &occurrenceDate = QDateTime());
     Q_INVOKABLE bool hasChildren(KCalendarCore::Incidence::Ptr incidence);
     void deleteAllChildren(KCalendarCore::Incidence::Ptr incidence);
     Q_INVOKABLE void deleteIncidence(KCalendarCore::Incidence::Ptr incidence, bool deleteChildren = false);
@@ -87,6 +92,7 @@ public:
     Q_INVOKABLE void undoAction();
     Q_INVOKABLE void redoAction();
 
+    Q_INVOKABLE void updateAllCollections();
     Q_INVOKABLE void updateCollection(qint64 collectionId);
     Q_INVOKABLE void deleteCollection(qint64 collectionId);
     Q_INVOKABLE void editCollection(qint64 collectionId);
