@@ -5,13 +5,22 @@
 
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
+#include <KCalUtils/RecurrenceActions>
 #include <QByteArray>
 #include <QObject>
 #include <akonadi_version.h>
 #if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/CollectionIdentificationAttribute>
+#include <Akonadi/Item>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/ItemMonitor>
 #else
 #include <AkonadiCore/CollectionIdentificationAttribute>
+#include <AkonadiCore/Item>
+#include <AkonadiCore/ItemFetchJob>
+#include <AkonadiCore/ItemFetchScope>
+#include <AkonadiCore/ItemMonitor>
 #endif
 #include "attachmentsmodel.h"
 #include "attendeesmodel.h"
@@ -26,9 +35,10 @@
  * adding and editing the incidence in the collection of our choice.
  */
 
-class IncidenceWrapper : public QObject, public KCalendarCore::IncidenceBase::IncidenceObserver
+class IncidenceWrapper : public QObject, public Akonadi::ItemMonitor
 {
     Q_OBJECT
+    Q_PROPERTY(Akonadi::Item incidenceItem READ incidenceItem WRITE setIncidenceItem NOTIFY incidenceItemChanged)
     Q_PROPERTY(KCalendarCore::Incidence::Ptr incidencePtr READ incidencePtr WRITE setIncidencePtr NOTIFY incidencePtrChanged)
     Q_PROPERTY(KCalendarCore::Incidence::Ptr originalIncidencePtr READ originalIncidencePtr NOTIFY originalIncidencePtrChanged)
     Q_PROPERTY(int incidenceType READ incidenceType NOTIFY incidenceTypeChanged)
@@ -89,13 +99,20 @@ public:
     };
     Q_ENUM(IncidenceTypes)
 
+    enum RecurrenceActions {
+        AllOccurrences = KCalUtils::RecurrenceActions::AllOccurrences,
+        SelectedOccurrence = KCalUtils::RecurrenceActions::SelectedOccurrence,
+        FutureOccurrences = KCalUtils::RecurrenceActions::FutureOccurrences,
+    };
+    Q_ENUM(RecurrenceActions)
+
     IncidenceWrapper(QObject *parent = nullptr);
     ~IncidenceWrapper() override;
 
-    void incidenceUpdate(const QString &uid, const QDateTime &recurrenceId) override;
-    void incidenceUpdated(const QString &uid, const QDateTime &recurrenceId) override;
     void notifyDataChanged();
 
+    Akonadi::Item incidenceItem() const;
+    void setIncidenceItem(const Akonadi::Item &incidenceItem);
     KCalendarCore::Incidence::Ptr incidencePtr() const;
     void setIncidencePtr(KCalendarCore::Incidence::Ptr incidencePtr);
     KCalendarCore::Incidence::Ptr originalIncidencePtr();
@@ -120,13 +137,13 @@ public:
     float geoLongitude() const;
 
     QDateTime incidenceStart() const;
-    void setIncidenceStart(const QDateTime &incidenceStart, bool respectTimeZone = false);
+    Q_INVOKABLE void setIncidenceStart(const QDateTime &incidenceStart, bool respectTimeZone = false);
     Q_INVOKABLE void setIncidenceStartDate(int day, int month, int year);
     Q_INVOKABLE void setIncidenceStartTime(int hours, int minutes);
     QString incidenceStartDateDisplay() const;
     QString incidenceStartTimeDisplay() const;
     QDateTime incidenceEnd() const;
-    void setIncidenceEnd(const QDateTime &incidenceEnd, bool respectTimeZone = false);
+    Q_INVOKABLE void setIncidenceEnd(const QDateTime &incidenceEnd, bool respectTimeZone = false);
     Q_INVOKABLE void setIncidenceEndDate(int day, int month, int year);
     Q_INVOKABLE void setIncidenceEndTime(int hours, int minutes);
     QString incidenceEndDateDisplay() const;
@@ -168,8 +185,7 @@ public:
     Q_INVOKABLE void clearRecurrences();
 
 Q_SIGNALS:
-    void incidenceChanged();
-    void incidenceAboutToChange();
+    void incidenceItemChanged();
     void incidencePtrChanged(KCalendarCore::Incidence::Ptr incidencePtr);
     void originalIncidencePtrChanged();
     void incidenceTypeChanged();
@@ -203,10 +219,13 @@ Q_SIGNALS:
     void todoPercentCompleteChanged();
     void attendeesChanged();
 
+protected:
+    void itemChanged(const Akonadi::Item &item) override;
+
 private:
     KCalendarCore::Incidence::Ptr m_incidence;
     KCalendarCore::Incidence::Ptr m_originalIncidence;
-    qint64 m_collectionId;
+    qint64 m_collectionId = -1; // For when we want to edit, this is temporary
     RemindersModel m_remindersModel;
     AttendeesModel m_attendeesModel;
     RecurrenceExceptionsModel m_recurrenceExceptionsModel;
