@@ -7,7 +7,7 @@
 #include "kalendarapplication.h"
 
 #include "commandbarfiltermodel.h"
-#include "kalendarconfig.h"
+#include "kalendar_debug.h"
 #include <CalendarSupport/Utils>
 #include <KAuthorized>
 #include <KConfigGroup>
@@ -367,6 +367,17 @@ void KalendarApplication::setupActions()
         mCollection.addAction(openKCommandBarAction->objectName(), openKCommandBarAction);
         mCollection.setDefaultShortcut(openKCommandBarAction, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_I));
     }
+
+    actionName = QLatin1String("refresh_all_calendars");
+    if (KAuthorized::authorizeAction(actionName)) {
+        auto refreshAllAction = mCollection.addAction(actionName, this, &KalendarApplication::refreshAllCalendars);
+        refreshAllAction->setText(i18n("Refresh All Calendars"));
+        refreshAllAction->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
+
+        mCollection.addAction(refreshAllAction->objectName(), refreshAllAction);
+        mCollection.setDefaultShortcut(refreshAllAction, QKeySequence(QKeySequence::Refresh));
+    }
+
     mSortCollection.readSettings();
     mCollection.readSettings();
 }
@@ -509,7 +520,7 @@ void KalendarApplication::importCalendarFromUrl(const QUrl &url, bool merge, qin
     } else {
         // empty error message means user canceled.
         if (!importer->errorMessage().isEmpty()) {
-            qDebug() << i18n("An error occurred: %1", importer->errorMessage());
+            qCDebug(KALENDAR_LOG) << i18n("An error occurred: %1", importer->errorMessage());
             m_importErrorMessage = importer->errorMessage();
             Q_EMIT importErrorMessageChanged();
         }
