@@ -10,11 +10,14 @@
 #include <KWindowConfig>
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
 #include <QDir>
 #include <QQmlApplicationEngine>
+#include <QQmlContext>
+#include <QQuickStyle>
 #include <QQuickWindow>
 #include <QUrl>
-#include <QtQml>
 #include <akonadi_version.h>
 #if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/AgentFilterProxyModel>
@@ -48,6 +51,15 @@ int main(int argc, char *argv[])
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
     QCoreApplication::setApplicationName(QStringLiteral("Kalendar"));
 
+    // Default to org.kde.desktop style unless the user forces another style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+
+#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif
+
     KAboutData aboutData(
         // The program name used internally.
         QStringLiteral("kalendar"),
@@ -154,5 +166,7 @@ int main(int argc, char *argv[])
         }
     }
 
+    QDBusConnection::sessionBus().interface()->startService(QStringLiteral("org.kde.kalendarac"));
+
     return app.exec();
 }
