@@ -6,12 +6,18 @@
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "multidayincidencemodel.h"
+#include "kalendar_debug.h"
 #include <QBitArray>
 
 MultiDayIncidenceModel::MultiDayIncidenceModel(QObject *parent)
     : QAbstractItemModel(parent)
 {
     mRefreshTimer.setSingleShot(true);
+    m_config = KalendarConfig::self();
+    QObject::connect(m_config, &KalendarConfig::showSubtodosInCalendarViewsChanged, this, [&]() {
+        beginResetModel();
+        endResetModel();
+    });
 }
 
 QModelIndex MultiDayIncidenceModel::index(int row, int column, const QModelIndex &parent) const
@@ -66,7 +72,7 @@ QList<QModelIndex> MultiDayIncidenceModel::sortedIncidencesFromSourceModel(const
 
         // Skip incidences not part of the week
         if (end < rowStart || start > rowEnd) {
-            // qWarning() << "Skipping because not part of this week";
+            // qCWarning(KALENDAR_LOG) << "Skipping because not part of this week";
             continue;
         }
 
@@ -74,7 +80,8 @@ QList<QModelIndex> MultiDayIncidenceModel::sortedIncidencesFromSourceModel(const
             continue;
         }
 
-        // qWarning() << "found " << srcIdx.data(IncidenceOccurrenceModel::StartTime).toDateTime() << srcIdx.data(IncidenceOccurrenceModel::Summary).toString();
+        // qCWarning(KALENDAR_LOG) << "found " << srcIdx.data(IncidenceOccurrenceModel::StartTime).toDateTime() <<
+        // srcIdx.data(IncidenceOccurrenceModel::Summary).toString();
         sorted.append(srcIdx);
     }
 
@@ -127,7 +134,8 @@ QVariantList MultiDayIncidenceModel::layoutLines(const QDate &rowStart) const
     QList<QModelIndex> sorted = sortedIncidencesFromSourceModel(rowStart);
 
     // for (const auto &srcIdx : sorted) {
-    //     qWarning() << "sorted " << srcIdx.data(IncidenceOccurrenceModel::StartTime).toDateTime() << srcIdx.data(IncidenceOccurrenceModel::Summary).toString()
+    //     qCWarning(KALENDAR_LOG) << "sorted " << srcIdx.data(IncidenceOccurrenceModel::StartTime).toDateTime() <<
+    //     srcIdx.data(IncidenceOccurrenceModel::Summary).toString()
     //     << srcIdx.data(IncidenceOccurrenceModel::AllDay).toBool();
     // }
 
@@ -140,7 +148,7 @@ QVariantList MultiDayIncidenceModel::layoutLines(const QDate &rowStart) const
         const auto start = getStart(srcIdx.data(IncidenceOccurrenceModel::StartTime).toDateTime().date());
         const auto duration = qMin(getDuration(startDate, srcIdx.data(IncidenceOccurrenceModel::EndTime).toDateTime().date()), mPeriodLength - start);
 
-        // qWarning() << "First of line " << srcIdx.data(IncidenceOccurrenceModel::StartTime).toDateTime() << duration <<
+        // qCWarning(KALENDAR_LOG) << "First of line " << srcIdx.data(IncidenceOccurrenceModel::StartTime).toDateTime() << duration <<
         // srcIdx.data(IncidenceOccurrenceModel::Summary).toString();
         auto currentLine = QVariantList{};
 
@@ -173,7 +181,7 @@ QVariantList MultiDayIncidenceModel::layoutLines(const QDate &rowStart) const
         };
 
         if (start >= mPeriodLength) {
-            // qWarning() << "Skipping " << srcIdx.data(IncidenceOccurrenceModel::Summary);
+            // qCWarning(KALENDAR_LOG) << "Skipping " << srcIdx.data(IncidenceOccurrenceModel::Summary);
             continue;
         }
 
@@ -191,7 +199,7 @@ QVariantList MultiDayIncidenceModel::layoutLines(const QDate &rowStart) const
         auto doesIntersect = [&](int start, int end) {
             for (int i = start; i < end; i++) {
                 if (takenSpaces[i]) {
-                    // qWarning() << "Found intersection " << start << end;
+                    // qCWarning(KALENDAR_LOG) << "Found intersection " << start << end;
                     return true;
                 }
             }
@@ -224,7 +232,7 @@ QVariantList MultiDayIncidenceModel::layoutLines(const QDate &rowStart) const
                 it = sorted.erase(it);
             }
         }
-        // qWarning() << "Appending line " << currentLine;
+        // qCWarning(KALENDAR_LOG) << "Appending line " << currentLine;
         result.append(QVariant::fromValue(currentLine));
     }
     return result;
@@ -303,20 +311,28 @@ void MultiDayIncidenceModel::setFilters(MultiDayIncidenceModel::Filters filters)
 
 bool MultiDayIncidenceModel::incidencePassesFilter(const QModelIndex &idx) const
 {
-    if (!m_filters) {
+    if (!m_filters && m_config->showSubtodosInCalendarViews()) {
         return true;
     }
     bool include = false;
-    const auto start = idx.data(IncidenceOccurrenceModel::StartTime).toDateTime().date();
 
-    if (m_filters.testFlag(AllDayOnly) && idx.data(IncidenceOccurrenceModel::AllDay).toBool()) {
-        include = true;
+    if (m_filters) {
+        const auto start = idx.data(IncidenceOccurrenceModel::StartTime).toDateTime().date();
+
+        if (m_filters.testFlag(AllDayOnly) && idx.data(IncidenceOccurrenceModel::AllDay).toBool()) {
+            include = true;
+        }
+
+        if (m_filters.testFlag(NoStartDateOnly) && !start.isValid()) {
+            include = true;
+        }
+        if (m_filters.testFlag(MultiDayOnly) && idx.data(IncidenceOccurrenceModel::Duration).value<KCalendarCore::Duration>().asDays() >= 1) {
+            include = true;
+        }
     }
 
-    if (m_filters.testFlag(NoStartDateOnly) && !start.isValid()) {
-        include = true;
-    }
-    if (m_filters.testFlag(MultiDayOnly) && idx.data(IncidenceOccurrenceModel::Duration).value<KCalendarCore::Duration>().asDays() >= 1) {
+    if (!m_config->showSubtodosInCalendarViews()
+        && idx.data(IncidenceOccurrenceModel::IncidencePtr).value<KCalendarCore::Incidence::Ptr>()->relatedTo().isEmpty()) {
         include = true;
     }
 
@@ -338,7 +354,7 @@ int MultiDayIncidenceModel::incidenceCount()
 
             // Skip incidences not part of the week
             if (end < rowStart || start > rowEnd) {
-                // qWarning() << "Skipping because not part of this week";
+                // qCWarning(KALENDAR_LOG) << "Skipping because not part of this week";
                 continue;
             }
 
